@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -35,6 +37,13 @@ class ApplyStackRequest(AbstractModel):
     def _deserialize(self, params):
         self.StackId = params.get("StackId")
         self.VersionId = params.get("VersionId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ApplyStackResponse(AbstractModel):
@@ -85,6 +94,13 @@ class CreateStackRequest(AbstractModel):
         self.StackRegion = params.get("StackRegion")
         self.TemplateUrl = params.get("TemplateUrl")
         self.Description = params.get("Description")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateStackResponse(AbstractModel):
@@ -139,6 +155,13 @@ class CreateStackVersionRequest(AbstractModel):
         self.TemplateUrl = params.get("TemplateUrl")
         self.VersionName = params.get("VersionName")
         self.Description = params.get("Description")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateStackVersionResponse(AbstractModel):
@@ -177,6 +200,13 @@ class DeleteStackRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.StackId = params.get("StackId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteStackResponse(AbstractModel):
@@ -211,6 +241,13 @@ class DeleteStackVersionRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.VersionId = params.get("VersionId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteStackVersionResponse(AbstractModel):
@@ -245,6 +282,13 @@ class DescribeStackEventRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.EventId = params.get("EventId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeStackEventResponse(AbstractModel):
@@ -305,27 +349,21 @@ class DescribeStackEventsRequest(AbstractModel):
         """
         :param EventIds: 按照⼀个或者多个事件ID查询
         :type EventIds: list of str
-        :param Filters: 过滤条件
-
-# VersionId
-按照版本ID过滤，VersionId形如 ver-kg8hn58h
+        :param Filters: <li>**VersionId**</li>
+按照【**版本ID**】过滤，VersionId形如 `ver-kg8hn58h`
 类型：string
-必须：否
 
-# StackId
-按照资源栈ID过滤，StackId形如 stk-hz5vn3te
+<li>**StackId**</li>
+按照【**资源栈ID**】过滤，StackId形如 `stk-hz5vn3te`
 类型：string
-必选：否
 
-# Type
-按照事件类型过滤，Type形如 plan, apply, destroy
+<li>**Type**</li>
+按照【**事件类型**】过滤，Type 形如 plan, apply, destroy
 类型：string
-必选：否
 
-# Status
-按照事件状态过滤，Status形如 queueing, running, success, failed
+<li>**Status**</li>
+按照【**事件状态**】过滤，Status形如 queueing, running, success, failed
 类型：string
-必选：否
         :type Filters: list of Filter
         :param Offset: 偏移量，默认为0。关于Offset的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/15688)中的相关小节
         :type Offset: int
@@ -348,6 +386,13 @@ class DescribeStackEventsRequest(AbstractModel):
                 self.Filters.append(obj)
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeStackEventsResponse(AbstractModel):
@@ -393,12 +438,16 @@ class DescribeStackVersionsRequest(AbstractModel):
         :type Offset: int
         :param Limit: 返回数量，默认为20，最大值为100。关于Limit的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/15688)中的相关小节
         :type Limit: int
-        :param Filters: # Name
-按照名称进行过滤，可选
+        :param Filters: <li>**Name**</li>
+按照【**版本名称**】进行过滤
 类型：string
 
-# Status
-按照版本状态过滤，形如VERSION_EDITING，PLAN_IN_PROGRESS等，可选
+<li>**Status**</li>
+按照【**版本状态**】过滤，形如`VERSION_EDITING`，`PLAN_IN_PROGRESS`等
+类型：string
+
+<li>**StackId**</li>
+按照版本所属的【**资源栈ID**】进行过滤，形如`stk-xxxxxx`
 类型：string
         :type Filters: list of Filter
         """
@@ -418,6 +467,13 @@ class DescribeStackVersionsRequest(AbstractModel):
                 obj = Filter()
                 obj._deserialize(item)
                 self.Filters.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeStackVersionsResponse(AbstractModel):
@@ -473,6 +529,13 @@ class DescribeStacksRequest(AbstractModel):
         self.StackIds = params.get("StackIds")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeStacksResponse(AbstractModel):
@@ -524,6 +587,13 @@ class DestroyStackRequest(AbstractModel):
     def _deserialize(self, params):
         self.StackId = params.get("StackId")
         self.VersionId = params.get("VersionId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DestroyStackResponse(AbstractModel):
@@ -586,6 +656,13 @@ class EventInfo(AbstractModel):
         self.Status = params.get("Status")
         self.Message = params.get("Message")
         self.CreateTime = params.get("CreateTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Filter(AbstractModel):
@@ -607,6 +684,13 @@ class Filter(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Values = params.get("Values")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class PlanStackRequest(AbstractModel):
@@ -628,6 +712,13 @@ class PlanStackRequest(AbstractModel):
     def _deserialize(self, params):
         self.StackId = params.get("StackId")
         self.VersionId = params.get("VersionId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class PlanStackResponse(AbstractModel):
@@ -686,6 +777,13 @@ class StackInfo(AbstractModel):
         self.Region = params.get("Region")
         self.Status = params.get("Status")
         self.CreateTime = params.get("CreateTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateStackRequest(AbstractModel):
@@ -711,6 +809,13 @@ class UpdateStackRequest(AbstractModel):
         self.StackId = params.get("StackId")
         self.StackName = params.get("StackName")
         self.Description = params.get("Description")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateStackResponse(AbstractModel):
@@ -757,6 +862,13 @@ class UpdateStackVersionRequest(AbstractModel):
         self.TemplateUrl = params.get("TemplateUrl")
         self.VersionName = params.get("VersionName")
         self.Description = params.get("Description")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateStackVersionResponse(AbstractModel):
@@ -810,4 +922,11 @@ class VersionInfo(AbstractModel):
         self.Description = params.get("Description")
         self.StackId = params.get("StackId")
         self.Status = params.get("Status")
-        self.CreateTime = params.get("CreateTime")
\ No newline at end of file
+        self.CreateTime = params.get("CreateTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
